Package: rfPred
Type: Package
Title: Assign rfPred functional prediction scores to a missense
        variants list
Version: 1.51.0
Date: 2025-07-23
Author: Fabienne Jabot-Hanin, Hugo Varet and Jean-Philippe Jais
Depends: R (>= 3.5.0), methods
Imports: utils, Seqinfo, data.table, IRanges, GenomicRanges, parallel,
        Rsamtools
Suggests: BiocStyle
Maintainer: Hugo Varet <varethugo@gmail.com>
Description: Based on external numerous data files where rfPred scores
        are pre-calculated on all genomic positions of the human exome,
        the package gives rfPred scores to missense variants identified
        by the chromosome, the position (hg19 version), the referent
        and alternative nucleotids and the uniprot identifier of the
        protein. Note that for using the package, the user has to download 
        the TabixFile and index (approximately 3.3 Go).
License: GPL (>=2 )
Encoding: UTF-8
biocViews: Software, Annotation, Classification
RoxygenNote: 7.3.2
git_url: https://git.bioconductor.org/packages/rfPred
git_branch: devel
git_last_commit: 491c390
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: yes
Packaged: 2026-04-29 00:38:41 UTC; biocbuild
