#' Toy example of data.frame
#'
#' @name variant_list_Y
#' @format A data frame with 5 observations on the following 5 variables:
#'   \describe{
#'     \item{\code{chr}}{Chromosome number (only \code{Y} in this example)}
#'     \item{\code{pos}}{Position on the chromosome (numeric)}
#'     \item{\code{ref}}{Referent nucleotid (\code{A}, \code{C}, \code{G} or \code{T})}
#'     \item{\code{alt}}{Alteration nucleotid (\code{A}, \code{C}, \code{G} or \code{T})}
#'     \item{\code{uniprot}}{Uniprot protein identifier (factor)}
#'   }
#' @docType data
#' @keywords data
NULL
