#' Toy example of GRanges object
#'
#' @name example_GRanges
#' @format A \code{GRanges} object with 11 rows and several columns:
#'   \describe{
#'     \item{\code{seqnames}}{Chromosome number (only \code{Y} in this example)}
#'     \item{\code{ranges}}{\code{IRanges} object for which \code{start}=\code{end}: position on the chromosome}
#'     \item{\code{reference}}{Referent nucleotid (\code{A}, \code{C}, \code{G} or \code{T})}
#'     \item{\code{alteration}}{Alteration nucleotid (\code{A}, \code{C}, \code{G} or \code{T})}
#'   }
#' @docType data
#' @keywords data
NULL
